==> tellico_2.1.1.orig.tar.bz2: tellico-2.1.1/src/tests/z3950fetchertest.h <==
/***************************************************************************
    Copyright (C) 2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef Z3950FETCHERTEST_H
#define Z3950FETCHERTEST_H

#include <QObject>
#include <QEventLoop>

#include "../datavectors.h"

class KJob;

class Z3950FetcherTest : public QObject {
Q_OBJECT
public:
  Z3950FetcherTest();

private Q_SLOTS:
  void initTestCase();
  void testTitle();
  void testIsbn();

  void slotResult(KJob* job);

private:
  QEventLoop m_loop;
  Tellico::Data::EntryList m_results;
};

#endif

==> tellico-2.3.12.tar.bz2: tellico-2.3.12/src/tests/z3950fetchertest.h <==
/***************************************************************************
    Copyright (C) 2009-2011 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef Z3950FETCHERTEST_H
#define Z3950FETCHERTEST_H

#include "abstractfetchertest.h"

class Z3950FetcherTest : public AbstractFetcherTest {
Q_OBJECT
public:
  Z3950FetcherTest();

private Q_SLOTS:
  void initTestCase();
  void testTitle();
  void testIsbn();
  void testADS();
};

#endif
